@@ -46,8 +46,8 @@ Puppet::Type.newtype(:designate_config) do
     defaultto('<SERVICE DEFAULT>')
   end
 
-  autorequire(:package) do
-    'designate-common'
+  autorequire(:anchor) do
+    ['designate::install::end']
   end
 
 end
