@@ -6,12 +6,13 @@ describe 'basic designate' do
 
     it 'should work with no errors' do
       pp= <<-EOS
-      include ::openstack_integration
-      include ::openstack_integration::repos
-      include ::openstack_integration::rabbitmq
-      include ::openstack_integration::mysql
-      include ::openstack_integration::keystone
-      include ::openstack_integration::designate
+      include openstack_integration
+      include openstack_integration::repos
+      include openstack_integration::apache
+      include openstack_integration::rabbitmq
+      include openstack_integration::mysql
+      include openstack_integration::keystone
+      include openstack_integration::designate
       EOS
 
       # Run it twice and test for idempotency
