@@ -55,10 +55,8 @@ describe 'designate::worker' do
         is_expected.to contain_designate_config('service:worker/poll_retry_interval').with_value( '<SERVICE DEFAULT>' )
         is_expected.to contain_designate_config('service:worker/poll_max_retries').with_value( '<SERVICE DEFAULT>' )
         is_expected.to contain_designate_config('service:worker/poll_delay').with_value( '<SERVICE DEFAULT>' )
-        is_expected.to contain_designate_config('service:worker/notify').with_value( '<SERVICE DEFAULT>' )
         is_expected.to contain_designate_config('service:worker/export_synchronous').with_value( '<SERVICE DEFAULT>' )
         is_expected.to contain_designate_config('service:worker/worker_topic').with_value( '<SERVICE DEFAULT>' )
-        is_expected.to contain_designate_config('service:worker/enabled').with_value( 'true' )
       end
     end
 
@@ -92,7 +90,6 @@ describe 'designate::worker' do
         is_expected.to contain_designate_config('service:worker/notify').with_value( params[:worker_notify] )
         is_expected.to contain_designate_config('service:worker/export_synchronous').with_value( params[:export_synchronous] )
         is_expected.to contain_designate_config('service:worker/worker_topic').with_value( params[:worker_topic] )
-        is_expected.to contain_designate_config('service:worker/enabled').with_value( params[:enabled] )
       end
     end
 
